@@ -1,18 +1,20 @@
 """Helper functions for handling classes defined with the package attrs."""
 
-from typing import Iterable, List, Tuple, Type
+from __future__ import annotations  # for ``Type[Any]``
+
+from typing import Any, Iterable, List, Tuple, Type
 
 from attr import Attribute
 
 
-def get_class_attributes(cls: Type) -> Iterable[Attribute]:
+def get_class_attributes(cls: Type[Any]) -> Iterable[Attribute[Any]]:
     """
     Return the attributes of a class declared with the attrs library.
     """
     return cls.__attrs_attrs__  # type: ignore
 
 
-def get_variables(cls: Type) -> List[str]:
+def get_variables(cls: Type[Any]) -> List[str]:
     """
     Return the names of the variables for a class declared with the attrs
     library.
@@ -20,7 +22,7 @@ def get_variables(cls: Type) -> List[str]:
     return [attribute.name for attribute in get_class_attributes(cls)]
 
 
-def get_variables_and_types(cls: Type) -> List[Tuple[str, Type]]:
+def get_variables_and_types(cls: Type[Any]) -> List[Tuple[str, Type[Any]]]:
     """
     Return the names of the variables and corresponding types for a class
     declared with the attrs library.
@@ -33,7 +35,7 @@ def get_variables_and_types(cls: Type) -> List[Tuple[str, Type]]:
     return result
 
 
-def get_variables_and_type_names(cls: Type) -> List[Tuple[str, str]]:
+def get_variables_and_type_names(cls: Type[Any]) -> List[Tuple[str, str]]:
     """
     Return the names of the variables and corresponding type names for a class
     declared with the attrs library.
