@@ -1,13 +1,18 @@
 import functools
 import logging
+from typing import Callable, TypeVar
 
 from diskcache import Cache
+from typing_extensions import ParamSpec
 
 logger = logging.getLogger(__name__)
 logger.addHandler(logging.NullHandler())
 
+Params = ParamSpec("Params")
+ReturnType = TypeVar("ReturnType")
 
-def cached_on_disk(func):
+
+def cached_on_disk(func: Callable[Params, ReturnType]) -> Callable[Params, ReturnType]:
     """
     Decorator for function cache relying on the disk.
 
@@ -29,11 +34,11 @@ def cached_on_disk(func):
     cache = Cache()
 
     @functools.wraps(func)
-    def wrapper(*args, **kwargs):
+    def wrapper(*args: Params.args, **kwargs: Params.kwargs) -> ReturnType:
         logger.debug(
             f"Cache miss: function {func.__name__}, args: {args}, kwargs: {kwargs}."
         )
 
         return func(*args, **kwargs)
 
-    return cache.memoize()(wrapper)
+    return cache.memoize()(wrapper)  # type: ignore
